@@ -53,6 +53,7 @@ def add_pipeline_files(project):
         'and numbers, and must start with a letter.'
     ))
 
+    project_short_name = None
     project_short_name_valid = False
 
     while not project_short_name_valid:
@@ -96,6 +97,19 @@ def add_pipeline_files(project):
 
     click.echo('Cloning %s' % clone_url)
 
+    _clone_pipeline_files(
+        project=project,
+        project_short_name=project_short_name,
+        clone_url=clone_url,
+    )
+
+
+def _clone_pipeline_files(project, project_short_name, clone_url):
+    """
+    :param Project project:
+    :param str project_short_name:
+    :param str clone_url:
+    """
     with tempfile.TemporaryDirectory() as temp_path:
         try:
             subprocess.check_call(
